auth

package
v0.1.129 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddSignature

func AddSignature(req *http.Request, encodedKeyID, encodedKey string) error

Verifies if the token signature is valid for a given request.

func NewAuthenticatedAPIClient

func NewAuthenticatedAPIClient(accessKey, secret string) *swagger.APIClient

NewAuthenticatedAPIClient initializes a new Crusoe API client with the given configuration.

func NewAuthenticatedConfig

func NewAuthenticatedConfig(accessKey, secret string) *swagger.Configuration

NewAuthenticatedConfig initializes a new Crusoe API configuration .

Types

type AuthenticatingTransport

type AuthenticatingTransport struct {
	http.RoundTripper
	// contains filtered or unexported fields
}

AuthenticatingTransport is a struct implementing http.Roundtripper that authenticates a request to Crusoe Cloud before sending it out.

func NewAuthenticatingTransport

func NewAuthenticatingTransport(r http.RoundTripper, keyID, secretKey string) AuthenticatingTransport

func (AuthenticatingTransport) RoundTrip

func (t AuthenticatingTransport) RoundTrip(r *http.Request) (*http.Response, error)

Jump to