Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddSignature ¶
Verifies if the token signature is valid for a given request.
func NewAuthenticatedAPIClient ¶
NewAuthenticatedAPIClient initializes a new Crusoe API client with the given configuration.
func NewAuthenticatedConfig ¶
func NewAuthenticatedConfig(accessKey, secret string) *swagger.Configuration
NewAuthenticatedConfig initializes a new Crusoe API configuration .
Types ¶
type AuthenticatingTransport ¶
type AuthenticatingTransport struct {
http.RoundTripper
// contains filtered or unexported fields
}
AuthenticatingTransport is a struct implementing http.Roundtripper that authenticates a request to Crusoe Cloud before sending it out.
func NewAuthenticatingTransport ¶
func NewAuthenticatingTransport(r http.RoundTripper, keyID, secretKey string) AuthenticatingTransport
Click to show internal directories.
Click to hide internal directories.